@@ -2,7 +2,7 @@ import os
 import json
 from datetime import datetime as dt
 
-from flask import Flask, jsonify, request
+from flask import Flask, jsonify, request, send_from_directory
 from flask_cors import CORS
 from sqlalchemy import create_engine
 
@@ -12,6 +12,17 @@ from hydenv.database import HydenvDatabase
 app = Flask(__name__)
 CORS(app)
 
+
+@app.route('/<path:path>', methods=['GET'])
+def static_files(path: str):
+    if path.endswith('js'):
+        return send_from_directory('./exercises-app/', path, mimetype='application/javascript')
+    return send_from_directory('./exercises-app/', path)
+
+@app.route('/')
+def index():
+    return send_from_directory('./', 'index.html')
+
 @app.route('/api/v1/ping', methods=['GET'])
 def ping():
     return jsonify({'message': 'I an here'}), 200
@@ -27,7 +38,7 @@ def execute():
     # get SQL query
     safe = data.get('safe', True)
     sql = data.get('sql')
-    explain = bool(data.get('explain', False))
+    explain = data.get('explain', False)
     if sql is None:
         return jsonify({'message': 'No SQL query given.'}), 404
     
@@ -61,8 +72,13 @@ def execute():
 
     # run explain if needed
     if explain:
+        # get the format
+        if explain not in ['text', 'json', 'xml', 'yaml']:
+            fmt = 'text'
+        else:
+            fmt = explain
         try:
-            exp_text = cli.explain(sql=sql, fmt='text')
+            exp_text = cli.explain(sql=sql, fmt=fmt)
         except Exception as e:
             exp_text = str(e)
         response['explain'] = exp_text
